OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "L'operador donat no és vàlid",
    "The given regular expression is invalid" : "L'expressió regular donada no és vàlida",
    "The given file size is invalid" : "La mida de fitxer donat no és vàlid",
    "The given tag id is invalid" : "L'Id d'etiqueta donat no és vàlid",
    "The given IP range is invalid" : "El rang d'IPs donat no és vàlid",
    "The given IP range is not valid for IPv4" : "El rang d'IP donat no és vàlid per IPv4",
    "The given IP range is not valid for IPv6" : "El rang d'IP donat no és vàlid per IPv6",
    "The given time span is invalid" : "El rang de temps donat no és vàlid",
    "The given start time is invalid" : "El temps d'inici donat no és vàlid",
    "The given end time is invalid" : "El temps de finalització donat no és vàlid",
    "The given group does not exist" : "El grup donat no existeix",
    "File" : "Fitxer",
    "File created" : "Fitxer creat",
    "File updated" : "Fitxer actualitzat",
    "File renamed" : "Fitxer reanomenat",
    "File deleted" : "Fitxer suprimit",
    "File accessed" : "Fitxer accedit",
    "File copied" : "Fitxer copiat",
    "Tag assigned" : "Etiqueta assignada",
    "Someone" : "Algú",
    "%s created %s" : "%s ha creat %s",
    "%s modified %s" : "%s ha modificat %s",
    "%s deleted %s" : "%s ha eliminat %s",
    "%s accessed %s" : "%s ha accedit %s",
    "%s renamed %s" : "%s ha renombrat %s",
    "%s copied %s" : "%s ha copiat %s",
    "%s assigned %s to %s" : "%s ha assignat %s a %s",
    "Operation #%s does not exist" : "L'operació #%s no existeix",
    "Entity %s does not exist" : "L'entitat %s no existeix",
    "Entity %s is invalid" : "L'entitat %s no és vàlida",
    "No events are chosen." : "No s'ha triat cap esdeveniment.",
    "Entity %s has no event %s" : "L'entitat %s no té cap esdeveniment %s",
    "Operation %s does not exist" : "L'operació %s no existeix",
    "Operation %s is invalid" : "L'operació %s no és vàlida",
    "At least one check needs to be provided" : "S'ha de proporcionar almenys una comprovació",
    "Invalid check provided" : "Comprovació no vàlida proporcionada",
    "Check %s does not exist" : "Comprovació %s no existeix",
    "Check %s is invalid" : "Comprovació %s no és vàlid",
    "Check %s is not allowed with this entity" : "La comprovació de %s no es permet amb aquesta entitat",
    "Check #%s does not exist" : "Comprovació #%s no existeix",
    "Check %s is invalid or does not exist" : "Comprovació %s no és vàlida o no existeix",
    "Flow" : "Flux",
    "Nextcloud workflow engine" : "Motor de flux de treball de Nextcloud",
    "Select a filter" : "Seleccioneu un filtre",
    "Select a comparator" : "Seleccioneu un comparador",
    "Select a file type" : "Seleccioneu un tipus de fitxer",
    "e.g. httpd/unix-directory" : "p. ex. httpd/unix-directory",
    "Folder" : "Carpeta",
    "Images" : "Imatges",
    "Office documents" : "Documents d'oficina",
    "PDF documents" : "Documents PDF",
    "Custom mimetype" : "Tipus mime personalitzat",
    "Please enter a valid time span" : "Introduïu un interval de temps vàlid",
    "Select a request URL" : "Seleccioneu un URL de petició",
    "Files WebDAV" : "Fitxers WebDAV",
    "Custom URL" : "URL personalitzat",
    "Select a user agent" : "Seleccioneu un agent d'usuari",
    "Android client" : "Client android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client d'escriptori",
    "Thunderbird & Outlook addons" : "Complements de Thunderbird i Outlook",
    "Custom user agent" : "Agent d'usuari personalitzat",
    "At least one event must be selected" : "Com a mínim s'ha de seleccionar un esdeveniment",
    "Add new flow" : "Afegeix un flux nou",
    "When" : "Quan",
    "and" : "i",
    "Cancel" : "Cancel·la",
    "Delete" : "Eliminar",
    "The configuration is invalid" : "La configuració no és vàlida",
    "Active" : "Actiu",
    "Save" : "Desa",
    "Available flows" : "Fluxos disponibles",
    "For details on how to write your own flow, check out the development documentation." : "Per obtenir més informació sobre com escriure el seu propi flux, feu un cop d'ulls a la documentació de desenvolupament.",
    "More flows" : "Més fluxos",
    "Browse the App Store" : "Navegueu per la botiga d’aplicacions",
    "Show less" : "Mostra'n menys",
    "Show more" : "Mostra'n més",
    "Configured flows" : "Fluxos configurats",
    "Your flows" : "Els seus fluxos",
    "matches" : "coincidències",
    "does not match" : "no encaixa",
    "is" : "és",
    "is not" : "no és",
    "File name" : "Nom del fitxer",
    "File MIME type" : "Tipus MIME del fitxer",
    "File size (upload)" : "Mida del fitxer (carrega)",
    "less" : "menys",
    "less or equals" : "menor o igual",
    "greater or equals" : "major o igual",
    "greater" : "superior",
    "Request remote address" : "Demana adreça remota",
    "matches IPv4" : "coincideix amb IPv4",
    "does not match IPv4" : "no encaixa amb IPv4",
    "matches IPv6" : "encaixa amb IPv6",
    "does not match IPv6" : "no encaixa amb IPv6",
    "File system tag" : "Etiqueta del sistema de fitxers",
    "is tagged with" : "està estiquetat amb",
    "is not tagged with" : "no està etiquetat amb",
    "Request URL" : "URL de sol·licitud",
    "Request time" : "Temps d'espera",
    "between" : "entre",
    "not between" : "no entre",
    "Request user agent" : "Sol·licita agent d'usuari",
    "is member of" : "és membre de",
    "is not member of" : "no és membre de",
    "User group membership" : "Pertinença a grup d'usuaris"
},
"nplurals=2; plural=(n != 1);");
